@@ -11,7 +11,7 @@ class addone(object):
     def addtest(self):
         print(self.number + 1)
         print('Random numpy integer: ' + str(np.random.randint(4)))
-        sample_df = pd.DataFrame(pd.read_csv('addonenishka/sample_data.csv'))
+        sample_df = pd.DataFrame(pd.read_csv('data/sample_data.csv'))
         print(sample_df.to_markdown())
 
 def main():
